@@ -1,4 +1,4 @@
-build.packages.install("uranium-plus[vscode]")
+build.packages.install("uranium-plus")
 import uranium_plus
 
 build.config.update({
